@@ -563,7 +563,7 @@ class CachePath(AugmentedPath):
             lc = self.local.meta.checksum
             cc = self.meta.checksum
             if lc != cc:
-                msg = f'Checksums do not match!\n(!=\n{lc}\n{cc}\n)'
+                msg = f'Checksums do not match!\n(!=\n{lc.hex()}\n{cc.hex()}\n)'
                 log.critical(msg)  # haven't figured out how to comput the bf checksums yet
                 #raise exc.ChecksumError(msg)
         elif meta.size is not None:
@@ -575,7 +575,7 @@ class CachePath(AugmentedPath):
                 raise exc.SizeError(f'Sizes do not match!\n(!=\n{ls}\n{cs}\n)')
         else:
             log.warning(f'No checksum and no size! Your data is at risk!\n'
-                        '{self.remote!r} -> {self.local!r}! ')
+                        f'{self.remote!r} -> {self.local!r}! ')
 
     @property
     def remote(self):
@@ -811,21 +811,28 @@ class CachePath(AugmentedPath):
             return new
         else:
             log.info(f'Remote for {self} has been deleted. Moving to trash.')
-            try:
-                self.rename(self._trashed_path)
-            except FileNotFoundError as e:
-                if not self.trash.exists():
-                    self.trash.mkdir()
-                    log.info('created {self.trash}')
-                else:
-                    raise e
+            trashed = self.crumple()
 
     def fetch(self, size_limit_mb=2):
         """ bypass remote to fetch directly based on stored meta """
         meta = self.meta
         if self.is_dir():
-            raise NotImplementedError('not going to fetch all data in a dir at the moment')
-        if meta.file_id is None:
+            msg = 'not going to fetch all data in a dir at the moment'
+            raise NotImplementedError(msg)
+        elif meta is None:
+            # XXX a stochastic error manifests here during a call to spc find
+            # some observations: I have seen it happen on files where there is
+            # a checksum mismatch, it might be the case that spc find trys to
+            # fetch the same file twice because it runs async and if two jobs
+            # run at the same time then there is a race where one writes the
+            # file before there is metadata and the other trys to read the
+            # cache metadata during that window, resulting in a failure
+            # the logs seem to support that this is what is happening
+            # because we get an error here AND also a log fetching the same file
+            # however I'm still not 100% sure that is the cause
+            msg = f'WAT: {self.as_posix()}'
+            raise exc.NoCachedMetadataError(msg)
+        elif meta.file_id is None:
             self.refresh(update_data=True, force=True)
             # the file name could be different so we have to return here
             return
@@ -856,7 +863,7 @@ class CachePath(AugmentedPath):
                 # FIXME these checks need to be happning inside of
                 # the local.data setter since otherwise this is overkill
                 #breakpoint()
-                msg = f'{_lc!r} != {meta.checksum!r} for {self!r}'
+                msg = f'{_lc.hex()!r} != {meta.checksum.hex()!r} for {self!r}'
                 log.critical(msg)
                 #raise BaseException()
 
@@ -1101,7 +1108,7 @@ class SymlinkCache(CachePath):
                            f'{meta.id} != {pathmeta.id}\n'
                            f'{meta.as_pretty()}\n'
                            f'{pathmeta.as_pretty()}')
-                    log.critical(msg)
+                    log.debug(msg)
                     meta_newer = 'Meta newer. Not updating.'
                     pathmeta_newer = 'Other meta newer.'
                     msg = '{}'  # apparently I was out of my mind when I wrote this originally ...
@@ -1110,33 +1117,33 @@ class SymlinkCache(CachePath):
                         return #FIXME
 
                     if meta.updated > pathmeta.updated:
-                        log.info(msg.format(meta_newer))
+                        log.debug(msg.format(meta_newer))
                         return  # this is the right thing to do for a sane filesystem
                     elif meta.updated < pathmeta.updated:
-                        log.info(msg.format(pathmeta_newer))
+                        log.debug(msg.format(pathmeta_newer))
                         # THIS IS EXPLICITLY ALLOWED
                     else:  # they are equal
                         extra = 'Both updated at the same time '
                         if meta.created is not None and pathmeta.created is not None:
                             if meta.created > pathmeta.created:
-                                log.info(msg.format(extra + meta_newer))
+                                log.debug(msg.format(extra + meta_newer))
                                 return
                             elif meta.created < pathmeta.created:
-                                log.info(msg.format(extra + pathmeta_newer))
+                                log.debug(msg.format(extra + pathmeta_newer))
                                 # THIS IS EXPLICITLY ALLOWED
                             else:  # same created
-                                log.info(msg.format('Identical timestamps. Not updating.'))
+                                log.debug(msg.format('Identical timestamps. Not updating.'))
                                 return
                         elif meta.created is not None:
-                            log.info(msg.format(extra + 'Meta has datetime other does not. Not updating.'))
+                            log.debug(msg.format(extra + 'Meta has datetime other does not. Not updating.'))
                             return
                         elif pathmeta.created is not None:
                             msg = msg.format(extra + 'Meta has no datetime other does.')
-                            log.info(msg)
+                            log.debug(msg)
                             raise exc.MetadataIdMismatchError(msg)
                         else:  # both none
-                            log.info(msg.format(extra + ('Identical update time both missing created time. '
-                                                         'Not updating.')))
+                            log.debug(msg.format(extra + ('Identical update time both missing created time. '
+                                                          'Not updating.')))
                             return
                     # equality
                 # id mismatch all cases above should return or raise except for other metadata newer
@@ -1269,7 +1276,12 @@ class PrimaryCache(CachePath):
                 continue
 
             if vold is not None and vold != vnew:
-                log.info(f'{old.id} field {k} changed from {vold} -> {vnew}')
+                if k == 'checksum':
+                    _vold, _vnew = vold.hex(), vnew.hex()
+                else:
+                    _vold, _vnew = vold, vnew
+
+                log.debug(f'{old.id} field {k} changed from {_vold} -> {_vnew}')
                 if k in ('created', 'updated', 'size', 'checksum', 'file_id'):
                     file_is_different = True
 
