@@ -143,10 +143,7 @@ class RepoHelper:
 
     path_relative_repo = repo_relative_path
 
-    def _remote_uri(self, prefix, infix=None, ref=None):
-        if isinstance(ref, self._git.Commit):
-            ref = str(ref)
-
+    def _remote_helper(self):
         repo = self.repo
         remote = repo.remote()
         rnprefix = remote.name + '/'
@@ -162,6 +159,14 @@ class RepoHelper:
             netloc = 'github.com'
             path = '/' + group + path
 
+        return repo, rnprefix, url_base, netloc, path
+
+    def _remote_uri(self, prefix, infix=None, ref=None):
+        if isinstance(ref, self._git.Commit):
+            ref = str(ref)
+
+        repo, rnprefix, url_base, netloc, path = self._remote_helper()
+
         if netloc == 'github.com':
 
             if not ref or ref == 'HEAD':
@@ -182,6 +187,12 @@ class RepoHelper:
         else:
             raise NotImplementedError(url_base)
 
+    def remote_uri_api(self, endpoint=''):
+        # technically this is for the whole repo
+        repo, rnprefix, url_base, netloc, path = self._remote_helper()
+        p = pathlib.PurePosixPath(path).with_suffix('')
+        return f'https://api.github.com/repos{p}' + endpoint
+
     def remote_uri_human(self, ref=None):
         return self._remote_uri('https://github.com', infix='blob', ref=ref)
 
